@@ -16,7 +16,7 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """cubicweb-squareui views/forms/actions/components for web ui"""
-from cubicweb.web.views.boxes import ContextualBoxLayout, contextual
+from cubicweb_web.views.boxes import ContextualBoxLayout, contextual
 
 
 class SimpleBoxContextFreeBoxLayout(ContextualBoxLayout):
