@@ -14,9 +14,9 @@ from logilab.mtconverter import xml_escape
 from cubicweb.schema import display_name
 from cubicweb.utils import UStringIO
 
-from cubicweb.web.views import basetemplates, basecomponents, actions
+from cubicweb_web.views import basetemplates, basecomponents, actions
 
-from cubicweb.web.views.boxes import SearchBox
+from cubicweb_web.views.boxes import SearchBox
 
 HTML5 = u'<!DOCTYPE html>'
 
