@@ -17,8 +17,8 @@
 
 from logilab.common.registry import yes
 
-from cubicweb.web.views.basecomponents import HeaderComponent
-from cubicweb.web.views.basetemplates import TheMainTemplate
+from cubicweb_web.views.basecomponents import HeaderComponent
+from cubicweb_web.views.basetemplates import TheMainTemplate
 
 
 class HideAsidesBar(HeaderComponent):
